@@ -31,4 +31,4 @@ fi
 icu_bin="$1" ; shift
 icu_lib="$1" ; shift
 # HP SHLIB_PATH too for old versions of HP-UX
-SHLIB_PATH=$icu_lib:$SHLIB_PATH LD_LIBRARY_PATH=$icu_lib:$LD_LIBRARY_PATH PATH=$icu_bin:$PATH exec genrb "$@"
+SHLIB_PATH=$icu_lib:$SHLIB_PATH LD_LIBRARY_PATH=$icu_lib:$LD_LIBRARY_PATH PATH=$icu_bin:$PATH genrb "$@"
