@@ -1109,13 +1109,12 @@ psetRootModAttribute(PsetRootPtr psetRoot, int mode, NameType name,
 {
   PsetPtr     pset = NULL;
   LDAPMod     **mods;
-  int         nameLen, nodeFlag, errorcode;
+  int         nodeFlag, errorcode;
   char        namebuf[256];
   char        *attrName, *nodeName;
   ValueType   valsptr;
   PsetNodePtr nodePtr;
 
-  nameLen = PL_strlen(name);
   PR_snprintf(namebuf, sizeof(namebuf), "%s", name);
   attrName = strrchr(namebuf, '.');
   if (!attrName) {
